# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Monitoring(_OCI):
    _type = "monitoring"
    _icon_dir = "resources/oci/monitoring"


class AlarmGrey(_Monitoring):
    _icon = "alarm-grey.png"


class Alarm(_Monitoring):
    _icon = "alarm.png"


class EventGrey(_Monitoring):
    _icon = "event-grey.png"


class Event(_Monitoring):
    _icon = "event.png"


class HealthcheckGrey(_Monitoring):
    _icon = "healthcheck-grey.png"


class Healthcheck(_Monitoring):
    _icon = "healthcheck.png"


class LoggingGrey(_Monitoring):
    _icon = "logging-grey.png"


class Logging(_Monitoring):
    _icon = "logging.png"


class NotificationsGrey(_Monitoring):
    _icon = "notifications-grey.png"


class Notifications(_Monitoring):
    _icon = "notifications.png"


class QueuingGrey(_Monitoring):
    _icon = "queuing-grey.png"


class Queuing(_Monitoring):
    _icon = "queuing.png"


class SearchGrey(_Monitoring):
    _icon = "search-grey.png"


class Search(_Monitoring):
    _icon = "search.png"


class StreamingGrey(_Monitoring):
    _icon = "streaming-grey.png"


class Streaming(_Monitoring):
    _icon = "streaming.png"


class TelemetryGrey(_Monitoring):
    _icon = "telemetry-grey.png"


class Telemetry(_Monitoring):
    _icon = "telemetry.png"


class WorkflowGrey(_Monitoring):
    _icon = "workflow-grey.png"


class Workflow(_Monitoring):
    _icon = "workflow.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Monitoring(_OnPrem):
    _type = "monitoring"
    _icon_dir = "resources/onprem/monitoring"


class Datadog(_Monitoring):
    _icon = "datadog.png"


class Grafana(_Monitoring):
    _icon = "grafana.png"


class Kibana(_Monitoring):
    _icon = "kibana.png"


class Prometheus(_Monitoring):
    _icon = "prometheus.png"


class Sentry(_Monitoring):
    _icon = "sentry.png"


class Splunk(_Monitoring):
    _icon = "splunk.png"


class Thanos(_Monitoring):
    _icon = "thanos.png"


# Aliases



print("import: 'diagrams'")
import diagrams

print("import: 'diagrams.alibabacloud'")
import diagrams.alibabacloud

print("import: 'diagrams.aws'")
import diagrams.aws

print("import: 'diagrams.azure'")
import diagrams.azure

print("import: 'diagrams.base'")
import diagrams.base

print("import: 'diagrams.custom'")
import diagrams.custom

print("import: 'diagrams.gcp'")
import diagrams.gcp

print("import: 'diagrams.k8s'")
import diagrams.k8s

print("import: 'diagrams.oci'")
import diagrams.oci

print("import: 'diagrams.onprem'")
import diagrams.onprem




# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AWS


class _General(_AWS):
    _type = "general"
    _icon_dir = "resources/aws/general"


class Disk(_General):
    _icon = "disk.png"


class General(_General):
    _icon = "general.png"


class GenericDatabase(_General):
    _icon = "generic-database.png"


class GenericFirewall(_General):
    _icon = "generic-firewall.png"


class GenericOfficeBuilding(_General):
    _icon = "generic-office-building.png"


class GenericSamlToken(_General):
    _icon = "generic-saml-token.png"


class GenericSDK(_General):
    _icon = "generic-sdk.png"


class Marketplace(_General):
    _icon = "marketplace.png"


class TradicionalServer(_General):
    _icon = "tradicional-server.png"


class User(_General):
    _icon = "user.png"


class Users(_General):
    _icon = "users.png"


# Aliases

OfficeBuilding = GenericOfficeBuilding



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Database(_OCI):
    _type = "database"
    _icon_dir = "resources/oci/database"


class DatabaseserviceGrey(_Database):
    _icon = "databaseservice-grey.png"


class Databaseservice(_Database):
    _icon = "databaseservice.png"


# Aliases

DBService = Databaseservice
DBServiceGrey = DatabaseserviceGrey



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Compute(_OCI):
    _type = "compute"
    _icon_dir = "resources/oci/compute"


class BmGrey(_Compute):
    _icon = "bm-grey.png"


class Bm(_Compute):
    _icon = "bm.png"


class ContainerGrey(_Compute):
    _icon = "container-grey.png"


class Container(_Compute):
    _icon = "container.png"


class VmGrey(_Compute):
    _icon = "vm-grey.png"


class Vm(_Compute):
    _icon = "vm.png"


# Aliases

VirtualMachine = Vm
VirtualMachineGrey = VmGrey
BareMetal = Bm
BareMetalGrey = BmGrey



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Edge(_OCI):
    _type = "edge"
    _icon_dir = "resources/oci/edge"


class CdnGrey(_Edge):
    _icon = "cdn-grey.png"


class Cdn(_Edge):
    _icon = "cdn.png"


class DnsGrey(_Edge):
    _icon = "dns-grey.png"


class Dns(_Edge):
    _icon = "dns.png"


class EmaildeliveryGrey(_Edge):
    _icon = "emaildelivery-grey.png"


class Emaildelivery(_Edge):
    _icon = "emaildelivery.png"


class WafGrey(_Edge):
    _icon = "waf-grey.png"


class Waf(_Edge):
    _icon = "waf.png"


# Aliases
